@@ -51,6 +51,8 @@ function(obj, seg.Z, psi=stop("provide psi"), control = seg.control(), model = T
     y <- model.response(mf, "any")
     XREG <- if (!is.empty.model(mt)) model.matrix(mt, mf, contrasts)
     namesXREG0<-colnames(XREG)
+    nameLeftSlopeZero<-setdiff(all.vars(seg.Z), all.vars(formula(obj)))
+    namesXREG0<-setdiff(namesXREG0, nameLeftSlopeZero)
     
     nomeRispo<-strsplit(paste(formula(obj))[2],"/")[[1]]
     if(length(nomeRispo)>=2) mf[nomeRispo[1]]<-weights*y
